"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SecureClientPasswordStrategyFactoryProvider = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const rest_1 = require("@loopback/rest");
// eslint-disable-next-line @typescript-eslint/naming-convention
const ClientPasswordStrategy = tslib_1.__importStar(require("./client-password-strategy"));
const types_1 = require("../../../types");
const keys_1 = require("../../keys");
let SecureClientPasswordStrategyFactoryProvider = class SecureClientPasswordStrategyFactoryProvider {
    constructor(verifier) {
        this.verifier = verifier;
    }
    value() {
        return (options, verifier) => this.getSecureClientPasswordVerifier(options, verifier);
    }
    secureClientPasswordVerifierHelper(client, clientSecret) {
        if (!client ||
            (client.clientType !== types_1.ClientType.public &&
                (!client.clientSecret || client.clientSecret !== clientSecret))) {
            throw new rest_1.HttpErrors.Unauthorized("Client Verification Failed" /* AuthErrorKeys.ClientVerificationFailed */);
        }
        else {
            // do nothing
        }
    }
    //prettier-ignore-start
    // prettier-ignore
    getSecureClientPasswordVerifier(options, verifierPassed) {
        const verifyFn = verifierPassed !== null && verifierPassed !== void 0 ? verifierPassed : this.verifier;
        if (options === null || options === void 0 ? void 0 : options.passReqToCallback) {
            return new ClientPasswordStrategy.Strategy((clientId, clientSecret, cb, req) => {
                verifyFn(clientId, clientSecret, req)
                    .then(client => {
                    this.secureClientPasswordVerifierHelper(client, clientSecret);
                    cb(null, client);
                })
                    .catch(err => {
                    cb(err);
                });
            }, options);
        }
        else {
            return new ClientPasswordStrategy.Strategy((clientId, clientSecret, cb) => {
                verifyFn(clientId, clientSecret)
                    .then(client => {
                    this.secureClientPasswordVerifierHelper(client, clientSecret);
                    cb(null, client);
                })
                    .catch(err => {
                    cb(err);
                });
            });
        }
    }
};
exports.SecureClientPasswordStrategyFactoryProvider = SecureClientPasswordStrategyFactoryProvider;
exports.SecureClientPasswordStrategyFactoryProvider = SecureClientPasswordStrategyFactoryProvider = tslib_1.__decorate([
    tslib_1.__param(0, (0, core_1.inject)(keys_1.Strategies.Passport.OAUTH2_CLIENT_PASSWORD_VERIFIER)),
    tslib_1.__metadata("design:paramtypes", [Function])
], SecureClientPasswordStrategyFactoryProvider);
//# sourceMappingURL=secure-client-password-strategy-factory-provider.js.map